==> apo-ws-client-6.00.10.4-sources.jar: fr/univlorraine/apowsclient/creationSE/CreerELPV2.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="elementPedagogi" type="{ElementPedagogiDTO6.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}ElementPedagogiDTO6" form="unqualified"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "elementPedagogi"
})
@XmlRootElement(name = "creerELP_v2", namespace = "gouv.education.apogee.commun.servicesmetiers.CreationSEMetier_17102019")
public class CreerELPV2 {

    @XmlElement(required = true)
    protected ElementPedagogiDTO6 elementPedagogi;

    /**
     * Obtient la valeur de la propriété elementPedagogi.
     * 
     * @return
     *     possible object is
     *     {@link ElementPedagogiDTO6 }
     *     
     */
    public ElementPedagogiDTO6 getElementPedagogi() {
        return elementPedagogi;
    }

    /**
     * Définit la valeur de la propriété elementPedagogi.
     * 
     * @param value
     *     allowed object is
     *     {@link ElementPedagogiDTO6 }
     *     
     */
    public void setElementPedagogi(ElementPedagogiDTO6 value) {
        this.elementPedagogi = value;
    }

}

==> apo-ws-client-6.00.50.2-sources.jar: fr/univlorraine/apowsclient/creationSE/CreerELPV2.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="elementPedagogi" type="{ElementPedagogiDTO6.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}ElementPedagogiDTO6" form="unqualified"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "elementPedagogi"
})
@XmlRootElement(name = "creerELP_v2", namespace = "gouv.education.apogee.commun.servicesmetiers.CreationSEMetier")
public class CreerELPV2 {

    @XmlElement(required = true)
    protected ElementPedagogiDTO6 elementPedagogi;

    /**
     * Obtient la valeur de la propriété elementPedagogi.
     * 
     * @return
     *     possible object is
     *     {@link ElementPedagogiDTO6 }
     *     
     */
    public ElementPedagogiDTO6 getElementPedagogi() {
        return elementPedagogi;
    }

    /**
     * Définit la valeur de la propriété elementPedagogi.
     * 
     * @param value
     *     allowed object is
     *     {@link ElementPedagogiDTO6 }
     *     
     */
    public void setElementPedagogi(ElementPedagogiDTO6 value) {
        this.elementPedagogi = value;
    }

}
